@@ -67,7 +67,12 @@ def check_genetic_models(variant_batch, family, verbose = False, proc_name = Non
         for variant_id in variant_batch[gene]:
             genotypes = {}
             for individual in family.individuals:
-                gt_info = variant_batch[gene][variant_id]['IDN:'+individual].split(':')[1].split('=')[1]
+                try:
+                    gt_info = variant_batch[gene][variant_id]['IDN:'+individual].split(':')[1].split('=')[1]
+                except (IndexError, KeyError):
+                    if verbose:
+                        print('Warning! Genotype info for variant %s is missing for individual %s.' % (variant_id, individual))
+                    gt_info = './.'
                 individual_genotype = genotype.Genotype(GT=gt_info)
                 genotypes[individual] = individual_genotype
             variant_batch[gene][variant_id]['Genotypes'] = genotypes
@@ -278,20 +283,26 @@ def check_parents(model, individual, variant, family):
             if ((mother_genotype.homo_alt or father_genotype.homo_alt) or 
                 (mother_genotype.has_variant and father_genotype.has_variant)):
                 variant['Inheritance_model']['AR_hom_denovo'] = False
-                # If de novo is true then the it is only de novo in this case
-            if variant['Inheritance_model']['AR_hom_denovo']:
+                return
+            # If both parents are called but none of the above is fullfilled it is denovo
+            elif not (mother_genotype.nocall or father_genotype.nocall):
                 variant['Inheritance_model']['AR_hom'] = False
-        else:   
+                
+        else:
+        #If one of the parents is missing it is not denovo only if a parents is homozygote alternative
             if (mother_genotype.homo_alt or father_genotype.homo_alt):
                 variant['Inheritance_model']['AR_hom_denovo'] = False
-                
-                
+                return
+                    
     elif model == 'dominant':
-    # If one of the parents have the variant on any form the de novo model is NOT followed.
-        if mother_genotype.has_variant or father_genotype.has_variant:
-            variant['Inheritance_model']['AD_denovo'] = False
-        if variant['Inheritance_model']['AD_denovo']:# If variant is ad de novo then it is not ad
+        # If none of the parents are affected and pattern is followed we have to have a de novo mutation.
+        if not (mother_phenotype == 2 or father_phenotype == 2):
             variant['Inheritance_model']['AD'] = False
+            return
+        # Else if one or both parents are affected it is de novo if none of them have a variant
+        elif mother_genotype.has_variant or father_genotype.has_variant:
+            variant['Inheritance_model']['AD_denovo'] = False
+            return
             
     elif model == 'X':
         #If the individual is a male:
