@@ -19,12 +19,12 @@ import multiprocessing
 
 class VariantPrinter(multiprocessing.Process):
     """docstring for VariantPrinter"""
-    def __init__(self, task_queue, outfile, lock, verbosity=False):
+    def __init__(self, task_queue, outfile, head, verbosity=False):
         multiprocessing.Process.__init__(self)
         self.task_queue = task_queue
         self.outfile = outfile
         self.verbosity = verbosity
-        self.lock = lock
+        self.header = head.header
     
     def run(self):
         """Starts the printing"""
@@ -32,20 +32,25 @@ class VariantPrinter(multiprocessing.Process):
         number_of_finished = 0
         proc_name = self.name
         if self.verbosity:
-            print proc_name ,'starting!'
+            print('%s starting!' % proc_name)
         while True:
             next_result = self.task_queue.get()
             if self.verbosity:
                 if self.task_queue.full():
-                    print 'Printing queue full'
+                    print('Printing queue full')
             if next_result is None:
                 if self.verbosity:
-                    print 'All variants printed!'
+                    print('All variants printed!')
                 self.outfile.close()
                 break
             else:
                 for variant_id in next_result:
-                    self.outfile.write('\t'.join(next_result[variant_id].values()) + '\n')
+                    try:
+                        print_line = [next_result[variant_id].get(entry, '-') for entry in self.header]
+                        self.outfile.write('\t'.join(print_line) + '\n')
+                    except TypeError as e:
+                        print(next_result[variant_id])
+                        print(e)
         return
 
 def main():
